==> vue-panel-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/panel/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { iconChevronDown, iconChevronRight } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconChevronDown: iconChevronDown(),
    IconChevronRight: iconChevronRight()
  },
  props: [].concat(props, ["expand", "foot", "head", "iconOpen", "iconClose", "isToggle", "transition"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-panel"
  }, [_c("div", {
    class: ["tiny-panel__head", {
      "tiny-panel__head-toggle": _vm.isToggle,
      "tiny-panel__collapse": !_vm.state.isShow
    }],
    on: {
      "click": _vm.toggle
    }
  }, [_vm._t("collapse", function() {
    return [_c(_vm.state.isShow ? _vm.iconOpen : _vm.iconClose, {
      tag: "component",
      class: ["panel-icon", "tiny-svg-size", {
        "head-span": _vm.state.isShow
      }]
    })];
  }, {
    "slotScope": {
      state: _vm.state,
      iconOpen: _vm.iconOpen,
      iconClose: _vm.iconClose,
      isToggle: _vm.isToggle
    }
  }), _vm._t("header", function() {
    return [_c("h3", {
      staticClass: "tiny-panel__title"
    }, [_vm._v(_vm._s(_vm.head))])];
  })], 2), _c("transition", {
    attrs: {
      "name": _vm.transition
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isShow,
      expression: "state.isShow"
    }],
    staticClass: "tiny-panel__body"
  }, [_vm._t("default")], 2)]), _vm._t("footer", function() {
    return [_c("div", {
      staticClass: "tiny-panel__footer"
    }, [_vm._v(_vm._s(_vm.foot))])];
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-panel-2.23.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/panel/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconChevronDown, iconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconChevronDown: iconChevronDown(),
    IconChevronRight: iconChevronRight()
  },
  emits: ["expand", "collapse"],
  props: [].concat(props, ["expand", "foot", "head", "iconOpen", "iconClose", "isToggle", "transition"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-panel"
  }, [_c("div", {
    class: ["tiny-panel__head", {
      "tiny-panel__head-toggle": _vm.isToggle,
      "tiny-panel__collapse": !_vm.state.isShow
    }],
    on: {
      "click": _vm.toggle
    }
  }, [_vm._t("collapse", function() {
    return [_c(_vm.state.isShow ? _vm.iconOpen : _vm.iconClose, {
      tag: "component",
      class: ["panel-icon", "tiny-svg-size", {
        "head-span": _vm.state.isShow
      }]
    })];
  }, {
    "slotScope": {
      state: _vm.state,
      iconOpen: _vm.iconOpen,
      iconClose: _vm.iconClose,
      isToggle: _vm.isToggle
    }
  }), _vm._t("header", function() {
    return [_c("h3", {
      staticClass: "tiny-panel__title"
    }, [_vm._v(_vm._s(_vm.head))])];
  })], 2), _c("transition", {
    attrs: {
      "name": _vm.transition
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isShow,
      expression: "state.isShow"
    }],
    staticClass: "tiny-panel__body"
  }, [_vm._t("default")], 2)]), _vm._t("footer", function() {
    return [_c("div", {
      staticClass: "tiny-panel__footer"
    }, [_vm._v(_vm._s(_vm.foot))])];
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
